@@ -3,13 +3,16 @@ package main
 import (
 	"context"
 	"fmt"
-	"github.com/skupperproject/skupper/pkg/utils/configs"
 	"os"
 	"reflect"
 	"strconv"
 	"strings"
 	"time"
 
+	"github.com/skupperproject/skupper/pkg/network"
+	"github.com/skupperproject/skupper/pkg/utils/configs"
+	"github.com/skupperproject/skupper/pkg/utils/validator"
+
 	routev1 "github.com/openshift/api/route/v1"
 	"github.com/skupperproject/skupper/pkg/domain"
 	"github.com/skupperproject/skupper/pkg/qdr"
@@ -81,11 +84,14 @@ type SkupperLinkClient interface {
 type SkupperTokenClient interface {
 	Create(cmd *cobra.Command, args []string) error
 	CreateFlags(cmd *cobra.Command)
+	GetCurrentSiteId(ctx context.Context) (string, error)
+	Status(cmd *cobra.Command, args []string) error
 	SkupperClientCommon
 }
 
 type SkupperNetworkClient interface {
-	Status(cmd *cobra.Command, args []string) error
+	GetCurrentSiteId(ctx context.Context) (string, error)
+	Status(cmd *cobra.Command, args []string, ctx context.Context) (*network.NetworkStatusInfo, error)
 	StatusFlags(cmd *cobra.Command)
 	SkupperClientCommon
 }
@@ -449,6 +455,16 @@ installation that can then be connected to other skupper installations`,
 				return fmt.Errorf("for the console to work with this user or password, the --console-auth option must be set to internal")
 			}
 
+			ok, err := validator.NewStringValidator().Evaluate(routerCreateOpts.SkupperName)
+			if !ok {
+				return fmt.Errorf("invalid skupper site name: %s", err.Error())
+			}
+
+			ok, err = validator.NewNumberValidator().Evaluate(routerCreateOpts.Routers)
+			if !ok {
+				return fmt.Errorf("invalid number for routers: %s", err.Error())
+			}
+
 			return skupperCli.Create(cmd, args)
 		},
 	}
@@ -869,9 +885,9 @@ func NewCmdVersion(skupperClient SkupperSiteClient) *cobra.Command {
 
 func NewCmdVersionManifest() *cobra.Command {
 	cmd := &cobra.Command{
-		Use:   "manifest",
-		Short: "Report the version of the Skupper images by default and the value of the environment variables",
-		Args:  cobra.NoArgs,
+		Use:  "manifest",
+		Long: "Generate a JSON file containing the version of the Skupper images by default and the value of the environment variables in the current directory.",
+		Args: cobra.NoArgs,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			silenceCobra(cmd)
 
@@ -1133,6 +1149,7 @@ func init() {
 
 	cmdToken := NewCmdToken()
 	cmdToken.AddCommand(NewCmdTokenCreate(skupperCli.Token(), ""))
+	cmdToken.AddCommand(NewCmdTokenStatus(skupperCli.Token(), ""))
 
 	cmdCompletion := NewCmdCompletion()
 
@@ -1142,7 +1159,6 @@ func init() {
 	cmdNetwork.AddCommand(NewCmdNetworkStatus(skupperCli.Network()))
 
 	cmdSwitch := NewCmdSwitch()
-	cmdSwitch.Hidden = true
 
 	addCommands(skupperCli, rootCmd,
 		cmdInit,
