@@ -14,8 +14,18 @@ const (
 
 var (
 	Username                = utils.ReadUsername()
-	SkupperContainerVolumes = []string{"skupper-services", "skupper-local-server", "skupper-internal", "skupper-site-server", SharedTlsCertificates,
-		types.ConsoleServerSecret, types.ConsoleUsersSecret, "prometheus-server-config", "prometheus-storage-volume"}
+	SkupperContainerVolumes = []string{
+		"skupper-services",
+		"skupper-local-server",
+		"skupper-internal",
+		"skupper-site-server",
+		SharedTlsCertificates,
+		types.ConsoleServerSecret,
+		types.ConsoleUsersSecret,
+		types.NetworkStatusConfigMapName,
+		"prometheus-server-config",
+		"prometheus-storage-volume",
+	}
 )
 
 func OwnedBySkupper(resource string, labels map[string]string) error {
