@@ -73,6 +73,7 @@ const (
 	SiteConfigRouterPodAnnotationsKey      string = "router-pod-annotations"
 	SiteConfigRouterLoadBalancerIp         string = "router-load-balancer-ip"
 	SiteConfigRouterDisableMutualTLS       string = "router-disable-mutual-tls"
+	SiteConfigRouterDropTcpConnections     string = "router-drop-tcp-connections"
 
 	// controller options
 	SiteConfigServiceControllerKey            string = "service-controller"
@@ -269,6 +270,9 @@ func WriteSiteConfig(spec types.SiteConfigSpec, namespace string) (*corev1.Confi
 	if spec.Router.DisableMutualTLS {
 		siteConfig.Data[SiteConfigRouterDisableMutualTLS] = "true"
 	}
+	if spec.Router.DropTcpConnections {
+		siteConfig.Data[SiteConfigRouterDropTcpConnections] = "true"
+	}
 	if spec.Controller.Cpu != "" {
 		if _, err := resource.ParseQuantity(spec.Controller.Cpu); err != nil {
 			errs = append(errs, fmt.Sprintf("Invalid value for %s %q: %s", SiteConfigControllerCpuKey, spec.Controller.Cpu, err))
@@ -672,6 +676,9 @@ func ReadSiteConfig(siteConfig *corev1.ConfigMap, namespace string, defaultIngre
 	if value, ok := siteConfig.Data[SiteConfigRouterDisableMutualTLS]; ok {
 		result.Spec.Router.DisableMutualTLS, _ = strconv.ParseBool(value)
 	}
+	if value, ok := siteConfig.Data[SiteConfigRouterDropTcpConnections]; ok {
+		result.Spec.Router.DropTcpConnections, _ = strconv.ParseBool(value)
+	}
 
 	if controllerCpu, ok := siteConfig.Data[SiteConfigControllerCpuKey]; ok && controllerCpu != "" {
 		result.Spec.Controller.Cpu = controllerCpu
