@@ -1,13 +1,14 @@
 package utils
 
 import (
-	"github.com/briandowns/spinner"
 	"time"
+
+	"github.com/briandowns/spinner"
 )
 
 func NewSpinner(message string, maxRetries int, function func() error) error {
 
-	spin := spinner.New(spinner.CharSets[9], 100*time.Millisecond)
+	spin := spinner.New(spinner.CharSets[9], 100*time.Millisecond, spinner.WithHiddenCursor(false))
 	spin.Prefix = message
 	spin.FinalMSG = message + "\n"
 
